@@ -1,13 +1,11 @@
 # coding: utf-8
-import json
-from collections import OrderedDict
 from io import BytesIO
 
 import pytest
 
 from img2table.document.pdf import PDF
 from img2table.ocr import TesseractOCR
-from img2table.tables.objects.extraction import ExtractedTable, BBox, TableCell
+from img2table.tables.objects.extraction import BBox
 
 
 def test_validators():
@@ -52,17 +50,18 @@ def test_pdf_tables(mock_tesseract):
 
     result = pdf.extract_tables(ocr=ocr, implicit_rows=True, min_confidence=50)
 
-    with open("test_data/extracted_tables.json", "r") as f:
-        expected = {
-            int(k): [ExtractedTable(title=tb.get('title'),
-                                    bbox=BBox(**tb.get('bbox')),
-                                    content=OrderedDict({int(id): [TableCell(bbox=BBox(**c.get('bbox')),
-                                                                             value=c.get('value'))
-                                                                   for c in row]
-                                                         for id, row in tb.get('content').items()})
-                                    )
-                     for tb in list_tbs]
-            for k, list_tbs in json.load(f).items()
-        }
+    assert result[0][0].title == "Example of Data Table 1"
+    assert result[0][0].bbox == BBox(x1=236, y1=249, x2=1442, y2=543)
+    assert (len(result[0][0].content), len(result[0][0].content[0])) == (5, 4)
 
-    assert result == expected
+    assert result[0][1].title == "Example of Data Table 2"
+    assert result[0][1].bbox == BBox(x1=235, y1=671, x2=1451, y2=971)
+    assert (len(result[0][1].content), len(result[0][1].content[0])) == (5, 4)
+
+    assert result[1][0].title == "Example of Data Table 3"
+    assert result[1][0].bbox == BBox(x1=236, y1=249, x2=1442, y2=543)
+    assert (len(result[1][0].content), len(result[1][0].content[0])) == (5, 4)
+
+    assert result[1][1].title == "Example of Data Table 4"
+    assert result[1][1].bbox == BBox(x1=235, y1=671, x2=1451, y2=971)
+    assert (len(result[1][1].content), len(result[1][1].content[0])) == (5, 4)
