@@ -6,18 +6,18 @@ from img2table.tables.processing.bordered_tables.cells.deduplication import dedu
 
 
 def test_deduplicate_nested_cells():
-    df_cells = pl.read_csv("test_data/expected_ident_cells.csv", sep=";", encoding="utf-8").lazy()
+    df_cells = pl.read_csv("test_data/expected_ident_cells.csv", separator=";", encoding="utf-8").lazy()
 
     result = deduplicate_nested_cells(df_cells=df_cells).collect()
-    expected = pl.read_csv("test_data/expected.csv", sep=";", encoding="utf-8")
+    expected = pl.read_csv("test_data/expected.csv", separator=";", encoding="utf-8")
 
     assert result.frame_equal(expected)
 
 
 def test_deduplicate_cells():
-    df_cells = pl.read_csv("test_data/expected_ident_cells.csv", sep=";", encoding="utf-8").lazy()
+    df_cells = pl.read_csv("test_data/expected_ident_cells.csv", separator=";", encoding="utf-8").lazy()
 
     result = deduplicate_cells(df_cells=df_cells).collect()
-    expected = pl.read_csv("test_data/expected.csv", sep=";", encoding="utf-8")
+    expected = pl.read_csv("test_data/expected.csv", separator=";", encoding="utf-8")
 
     assert result.frame_equal(expected)
